@@ -8,7 +8,7 @@ namespace Spotify
     class AlbumBrowser : public Spotify::TrackCollection
     {
         public:
-            AlbumBrowser( sp_albumbrowse* ab, QObject* parent = 0 );
+            AlbumBrowser(sp_session* session, sp_albumbrowse* ab, QObject* parent = 0 );
             sp_albumbrowse* getAlbumBrowser() const { return m_albumBrowser; }
             Spotify::Album* getAlbum() { return m_album; }
             Spotify::Artist* getArtist() { return m_artist; }
@@ -24,6 +24,7 @@ namespace Spotify
             ~AlbumBrowser();
 
         private:
+            sp_session* m_session;
             sp_albumbrowse* m_albumBrowser;
             Spotify::Album* m_album;
             Spotify::Artist* m_artist;
