@@ -131,6 +131,29 @@ void Spotify::Session::init()
     QByteArray cachePath = m_strCachePath.toLatin1();
     QByteArray settingsPath = m_strSettingsPath.toLatin1();
 
+    //make sure that necessary settings / cache directories exist
+
+    QDir cacheDir(m_strCachePath);
+    QDir settingsDir(m_strSettingsPath);
+
+    if(!cacheDir.exists())
+    {
+        if(!cacheDir.mkpath(m_strCachePath))
+        {
+            qDebug() << "Failed to create application cache directory " << m_strCachePath << ", exiting..";
+            qApp->quit();
+        }
+    }
+
+    if(!settingsDir.exists())
+    {
+        if(!settingsDir.mkpath(m_strSettingsPath))
+        {
+            qDebug() << "Failed to create application settings directory " << m_strSettingsPath << ", exiting..";
+            qApp->quit();
+        }
+    }
+
     // Set config parameters
     m_config.api_version = SPOTIFY_API_VERSION;
     m_config.cache_location = cachePath.data();
@@ -145,6 +168,7 @@ void Spotify::Session::init()
     if( m_error.isError() )
     {
         qDebug() << "FATAL ERROR: Could not initiate session. Error reason: " << m_error.toString();
+        qApp->quit();
     }
 
     m_pConnMan = new ConnectionManager(this); //allocate connection manager instance
@@ -392,6 +416,12 @@ void Spotify::Session::OnProcessThreadEvents()
             sp_session_process_events(m_session,&next_timeout);
 
             updateConnectionState(); //update connection state (in the case it has changed)
+
+            if (m_offlineMode && m_connState == SP_CONNECTION_STATE_LOGGED_IN)
+            {
+              setConnectionRule(SP_CONNECTION_RULE_NETWORK, true);
+              setConnectionRule(SP_CONNECTION_RULE_NETWORK, false);
+            }
         }
     }
     while(!next_timeout);
