@@ -23,12 +23,14 @@
         <translation>Albumin Arvosana</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="101"/>
+        <location filename="../src/AlbumView.cpp" line="102"/>
+        <location filename="../src/AlbumView.cpp" line="104"/>
         <source>Fetching of album details failed!</source>
         <translation>Albumin tietojen hakeminen epäonnistui!</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="134"/>
+        <location filename="../src/AlbumView.cpp" line="141"/>
+        <location filename="../src/AlbumView.cpp" line="143"/>
         <source>Fetching of album details failed: </source>
         <translation>Albumin tietojen hakeminen epäonnistui: </translation>
     </message>
@@ -51,17 +53,20 @@
         <translation>Biographia</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="81"/>
+        <location filename="../src/artistview.cpp" line="82"/>
+        <location filename="../src/artistview.cpp" line="84"/>
         <source>Fetching of artist details failed!</source>
         <translation>Artistin tietojen hakeminen epäonnistui!</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="86"/>
+        <location filename="../src/artistview.cpp" line="92"/>
+        <location filename="../src/artistview.cpp" line="95"/>
         <source>Loading </source>
         <translation>Ladataan</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="106"/>
+        <location filename="../src/artistview.cpp" line="117"/>
+        <location filename="../src/artistview.cpp" line="119"/>
         <source>Fetching of artist details failed: </source>
         <translation>Artistin tietojen hakeminen epäonnistui: </translation>
     </message>
@@ -69,89 +74,88 @@
 <context>
     <name>LoginDialog</name>
     <message>
-        <location filename="../src/logindialog.cpp" line="21"/>
+        <location filename="../src/logindialog.cpp" line="13"/>
         <source>QSpot - Login</source>
         <translation>QSpot - Kirjaudu sisään</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="24"/>
+        <location filename="../src/logindialog.cpp" line="16"/>
         <source>UserID:</source>
         <translation>Tunnus:</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="26"/>
+        <location filename="../src/logindialog.cpp" line="18"/>
         <source>Password:</source>
         <translation>Salasana:</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="29"/>
-        <location filename="../src/logindialog.cpp" line="180"/>
         <source>Remember UserID and password</source>
-        <translation>Muista kirjautumistiedot</translation>
+        <translation type="obsolete">Muista kirjautumistiedot</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Low bitrate (96kbps)</source>
-        <translation>Vähäinen (96 kt/s)</translation>
+        <translation type="obsolete">Vähäinen (96 kt/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Standard bitrate (160kbps)</source>
-        <translation>Normaali (160kt/s)</translation>
+        <translation type="obsolete">Normaali (160kt/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="36"/>
         <source>High bitrate (320kbps)</source>
-        <translation>Suuri (320kt/s)</translation>
+        <translation type="obsolete">Suuri (320kt/s)</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="44"/>
         <source>Preferred bitrate</source>
-        <translation>Toivottu siirtonopeus</translation>
+        <translation type="obsolete">Toivottu siirtonopeus</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="48"/>
+        <location filename="../src/logindialog.cpp" line="21"/>
         <source>Login</source>
         <translation>Kirjaudu sisään</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="186"/>
         <source>Remember UserID &amp;&amp; Pwd</source>
-        <translation>Muista minut</translation>
+        <translation type="obsolete">Muista minut</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="18"/>
+        <location filename="../src/MainWindow.cpp" line="16"/>
         <source>QSpot - Playlists</source>
         <translation>QSpot - Soittolistat</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="62"/>
-        <location filename="../src/MainWindow.cpp" line="570"/>
+        <location filename="../src/MainWindow.cpp" line="67"/>
+        <location filename="../src/MainWindow.cpp" line="721"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="63"/>
-        <location filename="../src/MainWindow.cpp" line="576"/>
+        <location filename="../src/MainWindow.cpp" line="69"/>
+        <location filename="../src/MainWindow.cpp" line="727"/>
         <source>FM Transmitter</source>
         <translation>FM-lähetin</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="64"/>
-        <location filename="../src/MainWindow.cpp" line="580"/>
+        <location filename="../src/MainWindow.cpp" line="71"/>
+        <location filename="../src/MainWindow.cpp" line="731"/>
         <source>About</source>
         <translation>Tietoa</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="179"/>
+        <location filename="../src/MainWindow.cpp" line="239"/>
+        <location filename="../src/MainWindow.cpp" line="241"/>
+        <source>Logging in to Spotify</source>
+        <translation>Kirjaudutaan Spotify:n</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="266"/>
         <source>About QSpot</source>
         <translation>Tietoa QSpotista</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
+        <location filename="../src/MainWindow.cpp" line="268"/>
         <source>QSpot version </source>
         <translation>QSpot-versio</translation>
     </message>
@@ -168,129 +172,170 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnitteelussa ja ulkoasussa.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
 
 (C) 2011 Andreas Enbacka and The QSpot Team.
 
 Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
-        <translation>Avoimeen lähdekoodiin, Qt-koodiin perustuva, Spotify-ohjelma N900/Maemo5:lle (perustuu libopenspotify:n).
+        <translation type="obsolete">Avoimeen lähdekoodiin, Qt-koodiin perustuva, Spotify-ohjelma N900/Maemo5:lle (perustuu libopenspotify:n).
 
 (C) 2011 Andreas Enbacka ja The QSpot Team.
 
 Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja ulkoasussa sekä Tomille (rantom@tomi) suomenkielelle kääntämisestä.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="406"/>
+        <location filename="../src/MainWindow.cpp" line="214"/>
+        <location filename="../src/MainWindow.cpp" line="224"/>
+        <location filename="../src/MainWindow.cpp" line="524"/>
         <source>Error:</source>
         <translation>Virhe:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="419"/>
+        <location filename="../src/MainWindow.cpp" line="224"/>
+        <source>No suitable internet access point(s) found!</source>
+        <translation>Käytettävää internet-yhteyttä ei löytynyt!</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="268"/>
+        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
+
+(C) 2011 Andreas Enbacka and The QSpot Team.
+
+Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations.</source>
+        <translation>Avoimeen lähdekoodiin, Qt-koodiin perustuva, Spotify-ohjelma N900/Maemo5:lle (perustuu libopenspotify:n).
+
+(C) 2011 Andreas Enbacka ja The QSpot Team.
+
+Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja ulkoasussa sekä Tomille (rantom@tmo) , Florianille (florian@tmo) ja Bennolle (bartus@tmo) käännöksistä.</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="544"/>
+        <location filename="../src/MainWindow.cpp" line="546"/>
         <source>Loading playlists</source>
         <translation>Ladataan soittolistoja</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="436"/>
+        <location filename="../src/MainWindow.cpp" line="570"/>
+        <location filename="../src/MainWindow.cpp" line="573"/>
         <source>Timeout occured while loading playlists!</source>
         <translation>Soittolistoja ladatessa tapahtui aikakatkaisu!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="464"/>
+        <location filename="../src/MainWindow.cpp" line="603"/>
         <source>tracks</source>
         <translation>kappaletta</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="602"/>
+        <location filename="../src/MainWindow.cpp" line="754"/>
+        <location filename="../src/MainWindow.cpp" line="757"/>
         <source>Searching</source>
         <translation>Etsitään</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="608"/>
-        <location filename="../src/MainWindow.cpp" line="623"/>
+        <location filename="../src/MainWindow.cpp" line="763"/>
+        <location filename="../src/MainWindow.cpp" line="766"/>
+        <location filename="../src/MainWindow.cpp" line="782"/>
+        <location filename="../src/MainWindow.cpp" line="784"/>
         <source>Error: </source>
         <translation>Virhe:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="642"/>
+        <location filename="../src/MainWindow.cpp" line="805"/>
+        <location filename="../src/MainWindow.cpp" line="807"/>
         <source>No tracks found!</source>
         <translation>Ei löytynyt kappaleita!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="656"/>
+        <location filename="../src/MainWindow.cpp" line="825"/>
+        <location filename="../src/MainWindow.cpp" line="827"/>
         <source>Playback paused due to the same account being used somewhere else!</source>
         <translation>Toisto keskeytettiin, koska tunnus on auki toisella koneella!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="666"/>
+        <location filename="../src/MainWindow.cpp" line="840"/>
+        <location filename="../src/MainWindow.cpp" line="842"/>
         <source>Last.fm error: </source>
         <translation>Last.fm-virhe: </translation>
     </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="940"/>
+        <location filename="../src/MainWindow.cpp" line="942"/>
+        <source>Failed to re-authenticate with Spotify</source>
+        <translation>Uudelleen varmistaminen epäonnistui</translation>
+    </message>
 </context>
 <context>
     <name>QueueView</name>
     <message>
         <location filename="../src/QueueView.cpp" line="15"/>
-        <location filename="../src/QueueView.cpp" line="859"/>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
+        <location filename="../src/QueueView.cpp" line="915"/>
+        <location filename="../src/QueueView.cpp" line="924"/>
+        <location filename="../src/QueueView.cpp" line="1084"/>
         <source>Now Playing</source>
         <translation>Nyt Soi</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="179"/>
+        <location filename="../src/QueueView.cpp" line="181"/>
         <source>Play Album</source>
         <translation>Soita Albumi</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="182"/>
+        <location filename="../src/QueueView.cpp" line="184"/>
         <source>Browse Album</source>
         <translation>Selaa Albumia</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="185"/>
+        <location filename="../src/QueueView.cpp" line="187"/>
         <source>Browse Artist</source>
         <translation>Selaa Artistia</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="199"/>
-        <location filename="../src/QueueView.cpp" line="206"/>
+        <location filename="../src/QueueView.cpp" line="202"/>
+        <location filename="../src/QueueView.cpp" line="210"/>
         <source>FM Transmitter</source>
         <translation>FM-lähetin</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="386"/>
-        <location filename="../src/QueueView.cpp" line="518"/>
-        <location filename="../src/QueueView.cpp" line="803"/>
-        <location filename="../src/QueueView.cpp" line="822"/>
+        <location filename="../src/QueueView.cpp" line="395"/>
+        <location filename="../src/QueueView.cpp" line="397"/>
+        <location filename="../src/QueueView.cpp" line="542"/>
+        <location filename="../src/QueueView.cpp" line="544"/>
+        <location filename="../src/QueueView.cpp" line="852"/>
+        <location filename="../src/QueueView.cpp" line="854"/>
+        <location filename="../src/QueueView.cpp" line="875"/>
+        <location filename="../src/QueueView.cpp" line="877"/>
         <source>Error starting track playback: </source>
         <translation>Virhe aloitettaessa kappaleen toistoa: </translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="514"/>
+        <location filename="../src/QueueView.cpp" line="533"/>
+        <location filename="../src/QueueView.cpp" line="535"/>
         <source>Buffering</source>
         <translation>Puskuroidaan</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="872"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
-        <location filename="../src/QueueView.cpp" line="1045"/>
+        <location filename="../src/QueueView.cpp" line="924"/>
+        <location filename="../src/QueueView.cpp" line="928"/>
+        <location filename="../src/QueueView.cpp" line="1084"/>
+        <location filename="../src/QueueView.cpp" line="1117"/>
         <source>Shuffle</source>
         <translation>Sekoitus</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="933"/>
+        <location filename="../src/QueueView.cpp" line="990"/>
+        <location filename="../src/QueueView.cpp" line="993"/>
         <source>Loading album tracks</source>
         <translation>Ladataan albumin kappaleita</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="954"/>
+        <location filename="../src/QueueView.cpp" line="1016"/>
+        <location filename="../src/QueueView.cpp" line="1018"/>
         <source>Fetching of album tracks failed: </source>
         <translation>Albumin kaikkien kappaleiden hakeminen epäonnistui: </translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="960"/>
+        <location filename="../src/QueueView.cpp" line="1027"/>
+        <location filename="../src/QueueView.cpp" line="1029"/>
         <source>Failed to load tracks!</source>
         <translation>Ei voitu ladata kappaleita!</translation>
     </message>
@@ -298,158 +343,198 @@ Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja u
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="191"/>
+        <location filename="../src/SettingsDialog.cpp" line="219"/>
+        <source>Remember UserID and password</source>
+        <translation>Muista kirjautumistiedot</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="49"/>
+        <source>Low bitrate (96kbps)</source>
+        <translation>Vähäinen (96 kt/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="49"/>
+        <source>Standard bitrate (160kbps)</source>
+        <translation>Normaali (160kt/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="50"/>
+        <source>High bitrate (320kbps)</source>
+        <translation>Suuri (320kt/s)</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Landscape</source>
         <translation>Vaaka</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Portrait</source>
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Automatic</source>
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="118"/>
-        <location filename="../src/SettingsDialog.cpp" line="142"/>
+        <location filename="../src/SettingsDialog.cpp" line="169"/>
+        <location filename="../src/SettingsDialog.cpp" line="198"/>
         <source>QSpot - Settings</source>
         <translation>QSpot - Asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="119"/>
+        <location filename="../src/SettingsDialog.cpp" line="170"/>
         <source>Max. tracks returned</source>
         <translation>Max. kappaleita tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="120"/>
+        <location filename="../src/SettingsDialog.cpp" line="171"/>
         <source>Max. albums returned</source>
         <translation>Max. albumeita tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="121"/>
+        <location filename="../src/SettingsDialog.cpp" line="172"/>
         <source>Max. artists returned</source>
         <translation>Max. artisteja tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="122"/>
-        <location filename="../src/SettingsDialog.cpp" line="146"/>
+        <location filename="../src/SettingsDialog.cpp" line="173"/>
+        <location filename="../src/SettingsDialog.cpp" line="202"/>
         <source>Search settings</source>
         <translation>Haun asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="123"/>
-        <location filename="../src/SettingsDialog.cpp" line="147"/>
+        <location filename="../src/SettingsDialog.cpp" line="174"/>
+        <location filename="../src/SettingsDialog.cpp" line="203"/>
         <source>Buffering settings</source>
         <translation>Puskuroinnin asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="124"/>
+        <location filename="../src/SettingsDialog.cpp" line="175"/>
         <source>Min. buffering length (secs)</source>
         <translation>Vähimmäis-puskuroinnin pituus (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="125"/>
+        <location filename="../src/SettingsDialog.cpp" line="176"/>
         <source>Enable track pre-buffering</source>
         <translation>Salli kappaleen esi-puskurointi</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="126"/>
-        <location filename="../src/SettingsDialog.cpp" line="150"/>
+        <location filename="../src/SettingsDialog.cpp" line="178"/>
+        <location filename="../src/SettingsDialog.cpp" line="207"/>
+        <source>Preferred bitrate</source>
+        <translation>Toivottu siirtonopeus</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="179"/>
+        <location filename="../src/SettingsDialog.cpp" line="208"/>
         <source>UI Language</source>
         <translation>Käytettävä kieli</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="127"/>
-        <location filename="../src/SettingsDialog.cpp" line="151"/>
+        <location filename="../src/SettingsDialog.cpp" line="180"/>
+        <location filename="../src/SettingsDialog.cpp" line="209"/>
         <source>Display orientation</source>
         <translation>Näytön suunta</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="128"/>
-        <location filename="../src/SettingsDialog.cpp" line="152"/>
+        <location filename="../src/SettingsDialog.cpp" line="182"/>
+        <location filename="../src/SettingsDialog.cpp" line="211"/>
         <source>Playlist options</source>
         <translation>Soittolistan valinnat</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="129"/>
+        <location filename="../src/SettingsDialog.cpp" line="183"/>
         <source>Playlist load timeout (secs)</source>
         <translation>Soittolistan latauksen aikakatkaisu (sekunteina)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="130"/>
-        <location filename="../src/SettingsDialog.cpp" line="154"/>
+        <location filename="../src/SettingsDialog.cpp" line="184"/>
+        <location filename="../src/SettingsDialog.cpp" line="213"/>
         <source>Pause on headset unplugged</source>
         <translation>Keskeytä toisto kuulokkeiden irrotessa</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="131"/>
-        <location filename="../src/SettingsDialog.cpp" line="155"/>
+        <location filename="../src/SettingsDialog.cpp" line="185"/>
+        <location filename="../src/SettingsDialog.cpp" line="214"/>
         <source>Scrobbling options</source>
         <translation>Julkistamisasetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="132"/>
+        <location filename="../src/SettingsDialog.cpp" line="186"/>
         <source>Enable scrobbling to Last.fm</source>
         <translation>Salli kappaleiden julkistaminen Last.fm:lle</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="133"/>
-        <location filename="../src/SettingsDialog.cpp" line="157"/>
+        <location filename="../src/SettingsDialog.cpp" line="187"/>
+        <location filename="../src/SettingsDialog.cpp" line="216"/>
         <source>Last.fm username</source>
         <translation>Last.fm-tunnus</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="134"/>
-        <location filename="../src/SettingsDialog.cpp" line="158"/>
+        <location filename="../src/SettingsDialog.cpp" line="188"/>
+        <location filename="../src/SettingsDialog.cpp" line="217"/>
         <source>Last.fm password</source>
         <translation>Last.fm-salasana</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="135"/>
-        <location filename="../src/SettingsDialog.cpp" line="159"/>
+        <location filename="../src/SettingsDialog.cpp" line="189"/>
+        <location filename="../src/SettingsDialog.cpp" line="218"/>
         <source>Save</source>
         <translation>Tallenna</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="143"/>
+        <location filename="../src/SettingsDialog.cpp" line="190"/>
+        <location filename="../src/SettingsDialog.cpp" line="220"/>
+        <source>Hide coverart in Now Playing</source>
+        <translation>Piilota kansikuva Nyt toistettavasta</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="199"/>
         <source>Max. tracks</source>
         <translation>Kappaleita enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="144"/>
+        <location filename="../src/SettingsDialog.cpp" line="200"/>
         <source>Max. albums</source>
         <translation>Albumeja enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="145"/>
+        <location filename="../src/SettingsDialog.cpp" line="201"/>
         <source>Max. artists</source>
         <translation>Artisteja enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="148"/>
+        <location filename="../src/SettingsDialog.cpp" line="204"/>
         <source>Min.buff.length (secs)</source>
         <translation>Vähimmäis-puskurointi (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="149"/>
+        <location filename="../src/SettingsDialog.cpp" line="205"/>
         <source>Enable track pre-buff.</source>
         <translation>Salli kappaleen esi-puskurointi.</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="153"/>
+        <location filename="../src/SettingsDialog.cpp" line="212"/>
         <source>Playlist load TO (secs)</source>
         <translation>Soittolistan latauksen aikakatkaisu (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="156"/>
+        <location filename="../src/SettingsDialog.cpp" line="215"/>
         <source>Enable Last.fm scrobbling</source>
         <translation>Salli Last.fm:lle julkistaminen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="275"/>
+        <location filename="../src/SettingsDialog.cpp" line="405"/>
+        <location filename="../src/SettingsDialog.cpp" line="407"/>
+        <source>Please restart QSpot for bitrate change to take effect!</source>
+        <translation>Käynnistä QSpot uudelleen ottaaksesi käyttöön siirtonopeuden muutokset!</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="421"/>
+        <location filename="../src/SettingsDialog.cpp" line="423"/>
         <source>Please restart QSpot for language change to take effect!</source>
         <translation>Käynnistä QSpot uudelleen ottaaksesi käyttöön kieliasetuksen muutokset!</translation>
     </message>
@@ -568,28 +653,31 @@ Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja u
         <translation>Artisti, albumi, kappale (nouseva)</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="81"/>
-        <location filename="../src/TrackView.cpp" line="190"/>
+        <location filename="../src/TrackView.cpp" line="83"/>
+        <location filename="../src/TrackView.cpp" line="210"/>
         <source>FM Transmitter</source>
         <translation>FM-lähetin</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="119"/>
+        <location filename="../src/TrackView.cpp" line="124"/>
+        <location filename="../src/TrackView.cpp" line="127"/>
         <source>Loading album tracks</source>
         <translation>Ladataan albumin kappaleita</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="155"/>
+        <location filename="../src/TrackView.cpp" line="165"/>
+        <location filename="../src/TrackView.cpp" line="167"/>
         <source>Fetching of album tracks failed: </source>
         <translation>Albumin kappaleiden hakeminen epäonnistui: </translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="161"/>
+        <location filename="../src/TrackView.cpp" line="176"/>
+        <location filename="../src/TrackView.cpp" line="178"/>
         <source>Failed to load tracks!</source>
         <translation>Ei voitu ladata kappaleita!</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="273"/>
+        <location filename="../src/TrackView.cpp" line="293"/>
         <source>Search results: </source>
         <translation>Haun tulokset: </translation>
     </message>
